.. Ibidas documentation master file, created by
   sphinx-quickstart on Mon Jan 17 11:09:37 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Ibidas's documentation!
==================================

Contents:

.. toctree::
   :maxdepth: 2

   installation
   tutorial
   basic_concepts

   ibidas_module
   ibidas_rep
   ibidas_type
   get_module

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

